@@ -4,16 +4,12 @@ use strict;
 use warnings;
 use parent qw(Tickit::WidgetRole);
 
-our $VERSION = '0.002';
+our $VERSION = '0.003';
 
 =head1 NAME
 
 Tickit::WidgetRole::Movable - support for resizable/movable "panels"
 
-=head1 VERSION
-
-Version 0.002
-
 =head1 SYNOPSIS
 
  package Tickit::Widget::MovingThing;
@@ -213,7 +209,7 @@ sub start_resize_from_corner {
 	$self->{_movable_role}{origin} = {
 		map { $_ => $win->$_ } qw(top left bottom right)
 	};
-	$win->{steal_input} = 1;
+	$win->set_steal_input(1);
 }
 
 =head2 start_resize_from_edge
@@ -231,7 +227,7 @@ sub start_resize_from_edge {
 	$self->{_movable_role}{origin} = {
 		map { $_ => $win->$_ } qw(top left bottom right)
 	};
-	$win->{steal_input} = 1;
+	$win->set_steal_input(1);
 }
 
 =head2 start_moving
@@ -249,7 +245,7 @@ sub start_moving {
 		line => $line,
 		col => $col,
 	};
-	$win->{steal_input} = 1;
+	$win->set_steal_input(1);
 }
 
 =head2 mouse_drag
@@ -398,7 +394,7 @@ On release make sure we hand back input to the previous handler.
 sub mouse_release {
 	my ($self, $v) = @_;
 	my $win = $self->window or die "no window?";
-	$win->{steal_input} = 0;
+	$win->set_steal_input(0);
 	$self->{_movable_role}{mouse_action} = '';
 }
 
@@ -433,8 +429,9 @@ __END__
 
 =head1 AUTHOR
 
-Tom Molesworth <cpan@perlsite.co.uk>
+Tom Molesworth <TEAM@cpan.org>
 
 =head1 LICENSE
 
-Copyright Tom Molesworth 2012-2014. Licensed under the same terms as Perl itself.
+Copyright Tom Molesworth 2012-2017. Licensed under the same terms as Perl itself.
+
